@@ -79,12 +79,17 @@ class DistributiveSpider(Spider):
         """
         from palp.conn import redis_conn
 
-        master_name = redis_conn.get(settings.REDIS_KEY_MASTER)
-        if master_name:
-            heart_beat = redis_conn.hget(settings.REDIS_KEY_HEARTBEAT, master_name.decode())
-            if not heart_beat:
+        master_detail = redis_conn.get(settings.REDIS_KEY_MASTER)
+        if master_detail:
+            master_detail = json.loads(master_detail.decode())
+            heart_beat = redis_conn.hget(settings.REDIS_KEY_HEARTBEAT, master_detail['name'])
+
+            # 没有心跳的情况下，master 创建时间不能与现在时间相差 5s 不然就有问题
+            if not heart_beat and time.time() - master_detail['time'] > 5:
                 redis_conn.delete(settings.REDIS_KEY_MASTER)
-            elif time.time() - json.loads(heart_beat.decode())['time'] > 30:
+
+            # 有心跳的情况下，master 超过 20s 没有跳动，就是有问题
+            elif time.time() - json.loads(heart_beat.decode())['time'] > 20:
                 redis_conn.delete(settings.REDIS_KEY_MASTER)
 
     @RunByThread(daemon=True)
@@ -191,7 +196,10 @@ class DistributiveSpider(Spider):
 
             # 设置 master 标志
             self.spider_master = True
-            redis_conn.set(settings.REDIS_KEY_MASTER, uuid.uuid1().hex.encode())
+            redis_conn.set(settings.REDIS_KEY_MASTER, json.dumps({
+                'name': str(uuid.uuid1().hex.encode()),
+                'time': time.time(),
+            }, ensure_ascii=False))
 
             # 删除停止标志
             redis_conn.delete(settings.REDIS_KEY_STOP)
